bayespy.inference.vmp.transformations.RotateGaussianARD.rotate
==============================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianARD.rotate